SteamID

Struct SteamID 

pub struct SteamID {
    pub universe: Universe,
    pub account_type: AccountType,
    pub instance: u32,
    pub account_id: u32,
}
Represents a Steam ID with all its components.

Fields

universe: Universe

The Steam universe this ID belongs to.

account_type: AccountType

The type of account this ID represents.

instance: u32

The instance of the account.

account_id: u32

The unique account identifier.

Implementations

Source

impl SteamID

pub fn new() -> Self

Creates a new invalid SteamID.

pub fn from_individual_account_id(account_id: u32) -> Self

Creates a SteamID from an individual account ID.

This is a convenience method for creating a typical user SteamID in the public universe with a desktop instance.

pub fn from_steam_id64(id: u64) -> Self

Parse a SteamID from a 64-bit integer.

pub fn is_valid(&self) -> bool

Returns whether Steam would consider this ID to be “valid”.

This does not check whether the given ID belongs to a real account, nor does it check that the given ID is for an individual account or in the public universe.

pub fn is_valid_individual(&self) -> bool

Returns whether this SteamID is valid and belongs to an individual user in the public universe with a desktop instance.

This is what most people think of when they think of a SteamID. Does not check whether the account actually exists.

pub fn is_group_chat(&self) -> bool

Checks whether this ID is for a legacy group chat.

pub fn is_lobby(&self) -> bool

Checks whether this ID is for a game lobby.

pub fn steam2(&self, newer_format: bool) -> Result<String, SteamIdError>

Renders the ID in Steam2 format (e.g. “STEAM_0:0:23071901”).

Arguments
  • newer_format - If true, use 1 as the first digit instead of 0 for the public universe.
Errors

Returns an error if this is not an individual account type.

pub fn steam3(&self) -> String

Renders the ID in Steam3 format (e.g. “[U:1:46143802]”).

pub fn steam_id64(&self) -> u64

Renders the ID in 64-bit decimal format.